@@ -38,6 +38,7 @@ from nise.util import LOG
 from nise.util import LOG_VERBOSITY
 from nise.yaml_gen import add_yaml_parser_args
 from nise.yaml_gen import yaml_main
+from oci.exceptions import InvalidConfig
 
 os.environ["TZ"] = "UTC"
 time.tzset()
@@ -240,6 +241,14 @@ def add_gcp_parser_args(parser):
     parser.add_argument(
         "-etag", "--gcp-etag", metavar="GCP_ETAG", dest="gcp_etag", required=False, help="The etag in the filename"
     )
+    parser.add_argument(
+        "-r",
+        "--resource-level",
+        dest="gcp_resource_level",
+        action="store_true",
+        required=False,
+        help="Whether to generate a resource level report",
+    )
 
 
 def add_ocp_parser_args(parser):
@@ -551,22 +560,32 @@ def _validate_oci_arguments(parser, options):
         (ParserError): If combination is invalid.
 
     """
-    is_args_valid = False
-    local_bucket = options.get("oci_local_bucket")
+
     bucket_name = options.get("oci_bucket_name")
-    config_file = os.environ.get("OCI_CONFIG_FILE")
-
-    if (not bucket_name) or (bucket_name and config_file and Path(config_file).exists()) or local_bucket:
-        is_args_valid = True
-    else:
-        msg = (
-            f"\n\t--oci-bucket-name {bucket_name} was supplied as an argument\n"
-            "\tbut a config file path is not set in your environment or does not exist locally."
-        )
-        msg = msg.format("--oci-bucket-name")
+    local_bucket = options.get("oci_local_bucket")
+    if not bucket_name or local_bucket:
+        return True
+    try:
+        config_file = os.environ.get("OCI_CONFIG_FILE")
+        if config_file and Path(config_file).exists():
+            return True
+        else:
+            oci_user = os.environ["OCI_USER"]
+            oci_fingerprint = os.environ["OCI_FINGERPRINT"]
+            oci_tenancy = os.environ["OCI_TENANCY"]
+            oci_credentials = os.environ["OCI_CREDENTIALS"]
+            oci_region = os.environ["OCI_REGION"]
+            oci_namespace = os.environ["OCI_NAMESPACE"]
+            if any(
+                (oci_var is None or oci_var == "")
+                for oci_var in [oci_user, oci_fingerprint, oci_tenancy, oci_credentials, oci_region, oci_namespace]
+            ):
+                raise InvalidConfig("Must provide valid config varibales")
+            return True
+    except (KeyError, InvalidConfig) as err:
+        msg = f"\n\t--oci-bucket-name {bucket_name} was supplied as an argument but missing a required variable {err}"  # noqa: E501
         parser.error(msg)
-
-    return is_args_valid
+        return False
 
 
 def _validate_provider_inputs(parser, options):
