@@ -15,6 +15,8 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 """Module for OCI compute data generation."""
+from random import uniform
+
 from nise.generators.oci.oci_generator import OCIGenerator
 
 
@@ -31,6 +33,13 @@ class OCIComputeGenerator(OCIGenerator):
         self.cost_product_description = "Virtual Machine Standard - E2 Micro - Free"
         self.cost_billing_unit = "ONE HOURS OCPUS"
         self.cost_sku_unit_description = "OCPU Hours"
-        self.usage_consumed_quant_units = "GB_MS"
+        self.usage_consumed_quant_units = "MS"
         self.usage_consumed_quant_measure = "STORAGE_SIZE"
         self.usage_product_resource = "PIC_COMPUTE_VM_STANDARD_E2_MICRO_FREE"
+        self.usage_consumed_quantity = self.fake.pyint(min_value=3600000, max_value=86400000)
+        self.unit_price = round(uniform(1.0, 10.0), 4)
+        self.cost = (
+            attributes.get("cost")
+            if attributes and attributes.get("cost")
+            else (self.unit_price * self.usage_consumed_quantity)
+        )
